# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatEditMessage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChatEditMessage.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15\x43hatEditMessage.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"h\n\x0f\x43hatEditMessage\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12\x0f\n\x07message\x18\x04 \x01(\t\"\xb9\x01\n\x17\x43hatEditMessageResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12\x17\n\x0fmessage_version\x18\x04 \x01(\x04\x12\x0f\n\x07message\x18\x05 \x01(\t\x12,\n\x0cmessage_type\x18\x06 \x01(\x0e\x32\x16.proto.RoomMessageTypeB&\n\x0enet.iGap.protoB\x14ProtoChatEditMessageb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHATEDITMESSAGE = _descriptor.Descriptor(
  name='ChatEditMessage',
  full_name='proto.ChatEditMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChatEditMessage.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatEditMessage.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChatEditMessage.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ChatEditMessage.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=181,
)


_CHATEDITMESSAGERESPONSE = _descriptor.Descriptor(
  name='ChatEditMessageResponse',
  full_name='proto.ChatEditMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChatEditMessageResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatEditMessageResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChatEditMessageResponse.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_version', full_name='proto.ChatEditMessageResponse.message_version', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ChatEditMessageResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='proto.ChatEditMessageResponse.message_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=369,
)

_CHATEDITMESSAGE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHATEDITMESSAGERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHATEDITMESSAGERESPONSE.fields_by_name['message_type'].enum_type = Global__pb2._ROOMMESSAGETYPE
DESCRIPTOR.message_types_by_name['ChatEditMessage'] = _CHATEDITMESSAGE
DESCRIPTOR.message_types_by_name['ChatEditMessageResponse'] = _CHATEDITMESSAGERESPONSE

ChatEditMessage = _reflection.GeneratedProtocolMessageType('ChatEditMessage', (_message.Message,), dict(
  DESCRIPTOR = _CHATEDITMESSAGE,
  __module__ = 'ChatEditMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatEditMessage)
  ))
_sym_db.RegisterMessage(ChatEditMessage)

ChatEditMessageResponse = _reflection.GeneratedProtocolMessageType('ChatEditMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHATEDITMESSAGERESPONSE,
  __module__ = 'ChatEditMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatEditMessageResponse)
  ))
_sym_db.RegisterMessage(ChatEditMessageResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoChatEditMessage'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserPrivacySetRule.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserPrivacySetRule.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18UserPrivacySetRule.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"{\n\x12UserPrivacySetRule\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.proto.PrivacyType\x12\"\n\x05level\x18\x03 \x01(\x0e\x32\x13.proto.PrivacyLevel\"\x85\x01\n\x1aUserPrivacySetRuleResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.proto.PrivacyType\x12\"\n\x05level\x18\x03 \x01(\x0e\x32\x13.proto.PrivacyLevelB)\n\x0enet.iGap.protoB\x17ProtoUserPrivacySetRuleb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERPRIVACYSETRULE = _descriptor.Descriptor(
  name='UserPrivacySetRule',
  full_name='proto.UserPrivacySetRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserPrivacySetRule.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.UserPrivacySetRule.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='proto.UserPrivacySetRule.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=203,
)


_USERPRIVACYSETRULERESPONSE = _descriptor.Descriptor(
  name='UserPrivacySetRuleResponse',
  full_name='proto.UserPrivacySetRuleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserPrivacySetRuleResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.UserPrivacySetRuleResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='proto.UserPrivacySetRuleResponse.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=339,
)

_USERPRIVACYSETRULE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERPRIVACYSETRULE.fields_by_name['type'].enum_type = Global__pb2._PRIVACYTYPE
_USERPRIVACYSETRULE.fields_by_name['level'].enum_type = Global__pb2._PRIVACYLEVEL
_USERPRIVACYSETRULERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERPRIVACYSETRULERESPONSE.fields_by_name['type'].enum_type = Global__pb2._PRIVACYTYPE
_USERPRIVACYSETRULERESPONSE.fields_by_name['level'].enum_type = Global__pb2._PRIVACYLEVEL
DESCRIPTOR.message_types_by_name['UserPrivacySetRule'] = _USERPRIVACYSETRULE
DESCRIPTOR.message_types_by_name['UserPrivacySetRuleResponse'] = _USERPRIVACYSETRULERESPONSE

UserPrivacySetRule = _reflection.GeneratedProtocolMessageType('UserPrivacySetRule', (_message.Message,), dict(
  DESCRIPTOR = _USERPRIVACYSETRULE,
  __module__ = 'UserPrivacySetRule_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserPrivacySetRule)
  ))
_sym_db.RegisterMessage(UserPrivacySetRule)

UserPrivacySetRuleResponse = _reflection.GeneratedProtocolMessageType('UserPrivacySetRuleResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERPRIVACYSETRULERESPONSE,
  __module__ = 'UserPrivacySetRule_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserPrivacySetRuleResponse)
  ))
_sym_db.RegisterMessage(UserPrivacySetRuleResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoUserPrivacySetRule'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetPromote.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetPromote.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16\x43lientGetPromote.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"3\n\x10\x43lientGetPromote\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xed\x01\n\x18\x43lientGetPromoteResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x38\n\x07promote\x18\x02 \x03(\x0b\x32\'.proto.ClientGetPromoteResponse.Promote\x1at\n\x07Promote\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.proto.ClientGetPromoteResponse.Promote.Type\x12\n\n\x02id\x18\x02 \x01(\x04\"!\n\x04Type\x12\x08\n\x04USER\x10\x00\x12\x0f\n\x0bPUBLIC_ROOM\x10\x01\x42\'\n\x0enet.iGap.protoB\x15ProtoClientGetPromoteb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.ClientGetPromoteResponse.Promote.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC_ROOM', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=322,
  serialized_end=355,
)
_sym_db.RegisterEnumDescriptor(_CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE)


_CLIENTGETPROMOTE = _descriptor.Descriptor(
  name='ClientGetPromote',
  full_name='proto.ClientGetPromote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetPromote.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=115,
)


_CLIENTGETPROMOTERESPONSE_PROMOTE = _descriptor.Descriptor(
  name='Promote',
  full_name='proto.ClientGetPromoteResponse.Promote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ClientGetPromoteResponse.Promote.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.ClientGetPromoteResponse.Promote.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=355,
)

_CLIENTGETPROMOTERESPONSE = _descriptor.Descriptor(
  name='ClientGetPromoteResponse',
  full_name='proto.ClientGetPromoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetPromoteResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='promote', full_name='proto.ClientGetPromoteResponse.promote', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTGETPROMOTERESPONSE_PROMOTE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=355,
)

_CLIENTGETPROMOTE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETPROMOTERESPONSE_PROMOTE.fields_by_name['type'].enum_type = _CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE
_CLIENTGETPROMOTERESPONSE_PROMOTE.containing_type = _CLIENTGETPROMOTERESPONSE
_CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE.containing_type = _CLIENTGETPROMOTERESPONSE_PROMOTE
_CLIENTGETPROMOTERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETPROMOTERESPONSE.fields_by_name['promote'].message_type = _CLIENTGETPROMOTERESPONSE_PROMOTE
DESCRIPTOR.message_types_by_name['ClientGetPromote'] = _CLIENTGETPROMOTE
DESCRIPTOR.message_types_by_name['ClientGetPromoteResponse'] = _CLIENTGETPROMOTERESPONSE

ClientGetPromote = _reflection.GeneratedProtocolMessageType('ClientGetPromote', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETPROMOTE,
  __module__ = 'ClientGetPromote_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPromote)
  ))
_sym_db.RegisterMessage(ClientGetPromote)

ClientGetPromoteResponse = _reflection.GeneratedProtocolMessageType('ClientGetPromoteResponse', (_message.Message,), dict(

  Promote = _reflection.GeneratedProtocolMessageType('Promote', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTGETPROMOTERESPONSE_PROMOTE,
    __module__ = 'ClientGetPromote_pb2'
    # @@protoc_insertion_point(class_scope:proto.ClientGetPromoteResponse.Promote)
    ))
  ,
  DESCRIPTOR = _CLIENTGETPROMOTERESPONSE,
  __module__ = 'ClientGetPromote_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPromoteResponse)
  ))
_sym_db.RegisterMessage(ClientGetPromoteResponse)
_sym_db.RegisterMessage(ClientGetPromoteResponse.Promote)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoClientGetPromote'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingGetConfiguration.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingGetConfiguration.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1fSignalingGetConfiguration.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"<\n\x19SignalingGetConfiguration\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xa9\x02\n!SignalingGetConfigurationResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x46\n\nice_server\x18\x02 \x03(\x0b\x32\x32.proto.SignalingGetConfigurationResponse.IceServer\x12\x15\n\rvoice_calling\x18\x03 \x01(\x08\x12\x15\n\rvideo_calling\x18\x04 \x01(\x08\x12\x16\n\x0escreen_sharing\x18\x05 \x01(\x08\x12\x13\n\x0bsecret_chat\x18\x06 \x01(\x08\x1a>\n\tIceServer\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x12\n\ncredential\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\tB0\n\x0enet.iGap.protoB\x1eProtoSignalingGetConfigurationb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SIGNALINGGETCONFIGURATION = _descriptor.Descriptor(
  name='SignalingGetConfiguration',
  full_name='proto.SignalingGetConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingGetConfiguration.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=133,
)


_SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER = _descriptor.Descriptor(
  name='IceServer',
  full_name='proto.SignalingGetConfigurationResponse.IceServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='proto.SignalingGetConfigurationResponse.IceServer.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='credential', full_name='proto.SignalingGetConfigurationResponse.IceServer.credential', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.SignalingGetConfigurationResponse.IceServer.username', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=433,
)

_SIGNALINGGETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='SignalingGetConfigurationResponse',
  full_name='proto.SignalingGetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingGetConfigurationResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ice_server', full_name='proto.SignalingGetConfigurationResponse.ice_server', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voice_calling', full_name='proto.SignalingGetConfigurationResponse.voice_calling', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='video_calling', full_name='proto.SignalingGetConfigurationResponse.video_calling', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='screen_sharing', full_name='proto.SignalingGetConfigurationResponse.screen_sharing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secret_chat', full_name='proto.SignalingGetConfigurationResponse.secret_chat', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=433,
)

_SIGNALINGGETCONFIGURATION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER.containing_type = _SIGNALINGGETCONFIGURATIONRESPONSE
_SIGNALINGGETCONFIGURATIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGGETCONFIGURATIONRESPONSE.fields_by_name['ice_server'].message_type = _SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER
DESCRIPTOR.message_types_by_name['SignalingGetConfiguration'] = _SIGNALINGGETCONFIGURATION
DESCRIPTOR.message_types_by_name['SignalingGetConfigurationResponse'] = _SIGNALINGGETCONFIGURATIONRESPONSE

SignalingGetConfiguration = _reflection.GeneratedProtocolMessageType('SignalingGetConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGGETCONFIGURATION,
  __module__ = 'SignalingGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetConfiguration)
  ))
_sym_db.RegisterMessage(SignalingGetConfiguration)

SignalingGetConfigurationResponse = _reflection.GeneratedProtocolMessageType('SignalingGetConfigurationResponse', (_message.Message,), dict(

  IceServer = _reflection.GeneratedProtocolMessageType('IceServer', (_message.Message,), dict(
    DESCRIPTOR = _SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER,
    __module__ = 'SignalingGetConfiguration_pb2'
    # @@protoc_insertion_point(class_scope:proto.SignalingGetConfigurationResponse.IceServer)
    ))
  ,
  DESCRIPTOR = _SIGNALINGGETCONFIGURATIONRESPONSE,
  __module__ = 'SignalingGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetConfigurationResponse)
  ))
_sym_db.RegisterMessage(SignalingGetConfigurationResponse)
_sym_db.RegisterMessage(SignalingGetConfigurationResponse.IceServer)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\036ProtoSignalingGetConfiguration'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupAddMember.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupAddMember.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14GroupAddMember.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xa5\x01\n\x0eGroupAddMember\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12,\n\x06member\x18\x03 \x01(\x0b\x32\x1c.proto.GroupAddMember.Member\x1a\x33\n\x06Member\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x18\n\x10start_message_id\x18\x02 \x01(\x04\"\x82\x01\n\x16GroupAddMemberResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12#\n\x04role\x18\x04 \x01(\x0e\x32\x15.proto.GroupRoom.RoleB%\n\x0enet.iGap.protoB\x13ProtoGroupAddMemberb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPADDMEMBER_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='proto.GroupAddMember.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupAddMember.Member.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_message_id', full_name='proto.GroupAddMember.Member.start_message_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=242,
)

_GROUPADDMEMBER = _descriptor.Descriptor(
  name='GroupAddMember',
  full_name='proto.GroupAddMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupAddMember.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddMember.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='proto.GroupAddMember.member', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPADDMEMBER_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=242,
)


_GROUPADDMEMBERRESPONSE = _descriptor.Descriptor(
  name='GroupAddMemberResponse',
  full_name='proto.GroupAddMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupAddMemberResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddMemberResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupAddMemberResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.GroupAddMemberResponse.role', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=375,
)

_GROUPADDMEMBER_MEMBER.containing_type = _GROUPADDMEMBER
_GROUPADDMEMBER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPADDMEMBER.fields_by_name['member'].message_type = _GROUPADDMEMBER_MEMBER
_GROUPADDMEMBERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPADDMEMBERRESPONSE.fields_by_name['role'].enum_type = Global__pb2._GROUPROOM_ROLE
DESCRIPTOR.message_types_by_name['GroupAddMember'] = _GROUPADDMEMBER
DESCRIPTOR.message_types_by_name['GroupAddMemberResponse'] = _GROUPADDMEMBERRESPONSE

GroupAddMember = _reflection.GeneratedProtocolMessageType('GroupAddMember', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _GROUPADDMEMBER_MEMBER,
    __module__ = 'GroupAddMember_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupAddMember.Member)
    ))
  ,
  DESCRIPTOR = _GROUPADDMEMBER,
  __module__ = 'GroupAddMember_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddMember)
  ))
_sym_db.RegisterMessage(GroupAddMember)
_sym_db.RegisterMessage(GroupAddMember.Member)

GroupAddMemberResponse = _reflection.GeneratedProtocolMessageType('GroupAddMemberResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPADDMEMBERRESPONSE,
  __module__ = 'GroupAddMember_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddMemberResponse)
  ))
_sym_db.RegisterMessage(GroupAddMemberResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoGroupAddMember'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FileDownload.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='FileDownload.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x12\x46ileDownload.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xe9\x01\n\x0c\x46ileDownload\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x11\n\tmax_limit\x18\x04 \x01(\x05\x12.\n\x08selector\x18\x05 \x01(\x0e\x32\x1c.proto.FileDownload.Selector\"V\n\x08Selector\x12\x08\n\x04\x46ILE\x10\x00\x12\x13\n\x0fSMALL_THUMBNAIL\x10\x01\x12\x13\n\x0fLARGE_THUMBNAIL\x10\x02\x12\x16\n\x12WAVEFORM_THUMBNAIL\x10\x03\"H\n\x14\x46ileDownloadResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05\x62ytes\x18\x04 \x01(\x0c\x42#\n\x0enet.iGap.protoB\x11ProtoFileDownloadb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_FILEDOWNLOAD_SELECTOR = _descriptor.EnumDescriptor(
  name='Selector',
  full_name='proto.FileDownload.Selector',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALL_THUMBNAIL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LARGE_THUMBNAIL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_THUMBNAIL', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=208,
  serialized_end=294,
)
_sym_db.RegisterEnumDescriptor(_FILEDOWNLOAD_SELECTOR)


_FILEDOWNLOAD = _descriptor.Descriptor(
  name='FileDownload',
  full_name='proto.FileDownload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.FileDownload.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.FileDownload.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='proto.FileDownload.offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_limit', full_name='proto.FileDownload.max_limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selector', full_name='proto.FileDownload.selector', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILEDOWNLOAD_SELECTOR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=294,
)


_FILEDOWNLOADRESPONSE = _descriptor.Descriptor(
  name='FileDownloadResponse',
  full_name='proto.FileDownloadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.FileDownloadResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='proto.FileDownloadResponse.bytes', index=1,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=368,
)

_FILEDOWNLOAD.fields_by_name['request'].message_type = Request__pb2._REQUEST
_FILEDOWNLOAD.fields_by_name['selector'].enum_type = _FILEDOWNLOAD_SELECTOR
_FILEDOWNLOAD_SELECTOR.containing_type = _FILEDOWNLOAD
_FILEDOWNLOADRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['FileDownload'] = _FILEDOWNLOAD
DESCRIPTOR.message_types_by_name['FileDownloadResponse'] = _FILEDOWNLOADRESPONSE

FileDownload = _reflection.GeneratedProtocolMessageType('FileDownload', (_message.Message,), dict(
  DESCRIPTOR = _FILEDOWNLOAD,
  __module__ = 'FileDownload_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileDownload)
  ))
_sym_db.RegisterMessage(FileDownload)

FileDownloadResponse = _reflection.GeneratedProtocolMessageType('FileDownloadResponse', (_message.Message,), dict(
  DESCRIPTOR = _FILEDOWNLOADRESPONSE,
  __module__ = 'FileDownload_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileDownloadResponse)
  ))
_sym_db.RegisterMessage(FileDownloadResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\021ProtoFileDownload'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelGetMessagesStats.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChannelGetMessagesStats.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1d\x43hannelGetMessagesStats.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"_\n\x17\x43hannelGetMessagesStats\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x03(\x04\"\xe7\x01\n\x1f\x43hannelGetMessagesStatsResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12;\n\x05stats\x18\x02 \x03(\x0b\x32,.proto.ChannelGetMessagesStatsResponse.Stats\x1a\x64\n\x05Stats\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x13\n\x0bviews_label\x18\x02 \x01(\t\x12\x17\n\x0fthumbs_up_label\x18\x03 \x01(\t\x12\x19\n\x11thumbs_down_label\x18\x04 \x01(\tB.\n\x0enet.iGap.protoB\x1cProtoChannelGetMessagesStatsb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHANNELGETMESSAGESSTATS = _descriptor.Descriptor(
  name='ChannelGetMessagesStats',
  full_name='proto.ChannelGetMessagesStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChannelGetMessagesStats.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelGetMessagesStats.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChannelGetMessagesStats.message_id', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=166,
)


_CHANNELGETMESSAGESSTATSRESPONSE_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='proto.ChannelGetMessagesStatsResponse.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChannelGetMessagesStatsResponse.Stats.message_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='views_label', full_name='proto.ChannelGetMessagesStatsResponse.Stats.views_label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='thumbs_up_label', full_name='proto.ChannelGetMessagesStatsResponse.Stats.thumbs_up_label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='thumbs_down_label', full_name='proto.ChannelGetMessagesStatsResponse.Stats.thumbs_down_label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=400,
)

_CHANNELGETMESSAGESSTATSRESPONSE = _descriptor.Descriptor(
  name='ChannelGetMessagesStatsResponse',
  full_name='proto.ChannelGetMessagesStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChannelGetMessagesStatsResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='proto.ChannelGetMessagesStatsResponse.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CHANNELGETMESSAGESSTATSRESPONSE_STATS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=400,
)

_CHANNELGETMESSAGESSTATS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHANNELGETMESSAGESSTATSRESPONSE_STATS.containing_type = _CHANNELGETMESSAGESSTATSRESPONSE
_CHANNELGETMESSAGESSTATSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHANNELGETMESSAGESSTATSRESPONSE.fields_by_name['stats'].message_type = _CHANNELGETMESSAGESSTATSRESPONSE_STATS
DESCRIPTOR.message_types_by_name['ChannelGetMessagesStats'] = _CHANNELGETMESSAGESSTATS
DESCRIPTOR.message_types_by_name['ChannelGetMessagesStatsResponse'] = _CHANNELGETMESSAGESSTATSRESPONSE

ChannelGetMessagesStats = _reflection.GeneratedProtocolMessageType('ChannelGetMessagesStats', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELGETMESSAGESSTATS,
  __module__ = 'ChannelGetMessagesStats_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMessagesStats)
  ))
_sym_db.RegisterMessage(ChannelGetMessagesStats)

ChannelGetMessagesStatsResponse = _reflection.GeneratedProtocolMessageType('ChannelGetMessagesStatsResponse', (_message.Message,), dict(

  Stats = _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), dict(
    DESCRIPTOR = _CHANNELGETMESSAGESSTATSRESPONSE_STATS,
    __module__ = 'ChannelGetMessagesStats_pb2'
    # @@protoc_insertion_point(class_scope:proto.ChannelGetMessagesStatsResponse.Stats)
    ))
  ,
  DESCRIPTOR = _CHANNELGETMESSAGESSTATSRESPONSE,
  __module__ = 'ChannelGetMessagesStats_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMessagesStatsResponse)
  ))
_sym_db.RegisterMessage(ChannelGetMessagesStatsResponse)
_sym_db.RegisterMessage(ChannelGetMessagesStatsResponse.Stats)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\034ProtoChannelGetMessagesStats'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserProfileCheckUsername.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserProfileCheckUsername.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1eUserProfileCheckUsername.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"M\n\x18UserProfileCheckUsername\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x10\n\x08username\x18\x02 \x01(\t\"\xb6\x01\n UserProfileCheckUsernameResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12>\n\x06status\x18\x02 \x01(\x0e\x32..proto.UserProfileCheckUsernameResponse.Status\"/\n\x06Status\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05TAKEN\x10\x01\x12\r\n\tAVAILABLE\x10\x02\x42/\n\x0enet.iGap.protoB\x1dProtoUserProfileCheckUsernameb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_USERPROFILECHECKUSERNAMERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.UserProfileCheckUsernameResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAKEN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=287,
  serialized_end=334,
)
_sym_db.RegisterEnumDescriptor(_USERPROFILECHECKUSERNAMERESPONSE_STATUS)


_USERPROFILECHECKUSERNAME = _descriptor.Descriptor(
  name='UserProfileCheckUsername',
  full_name='proto.UserProfileCheckUsername',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserProfileCheckUsername.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.UserProfileCheckUsername.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=149,
)


_USERPROFILECHECKUSERNAMERESPONSE = _descriptor.Descriptor(
  name='UserProfileCheckUsernameResponse',
  full_name='proto.UserProfileCheckUsernameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserProfileCheckUsernameResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.UserProfileCheckUsernameResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERPROFILECHECKUSERNAMERESPONSE_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=334,
)

_USERPROFILECHECKUSERNAME.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERPROFILECHECKUSERNAMERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERPROFILECHECKUSERNAMERESPONSE.fields_by_name['status'].enum_type = _USERPROFILECHECKUSERNAMERESPONSE_STATUS
_USERPROFILECHECKUSERNAMERESPONSE_STATUS.containing_type = _USERPROFILECHECKUSERNAMERESPONSE
DESCRIPTOR.message_types_by_name['UserProfileCheckUsername'] = _USERPROFILECHECKUSERNAME
DESCRIPTOR.message_types_by_name['UserProfileCheckUsernameResponse'] = _USERPROFILECHECKUSERNAMERESPONSE

UserProfileCheckUsername = _reflection.GeneratedProtocolMessageType('UserProfileCheckUsername', (_message.Message,), dict(
  DESCRIPTOR = _USERPROFILECHECKUSERNAME,
  __module__ = 'UserProfileCheckUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserProfileCheckUsername)
  ))
_sym_db.RegisterMessage(UserProfileCheckUsername)

UserProfileCheckUsernameResponse = _reflection.GeneratedProtocolMessageType('UserProfileCheckUsernameResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERPROFILECHECKUSERNAMERESPONSE,
  __module__ = 'UserProfileCheckUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserProfileCheckUsernameResponse)
  ))
_sym_db.RegisterMessage(UserProfileCheckUsernameResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\035ProtoUserProfileCheckUsername'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserVerifyNewDevice.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserVerifyNewDevice.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x19UserVerifyNewDevice.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"E\n\x13UserVerifyNewDevice\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05token\x18\x02 \x01(\t\"\xa2\x02\n\x1bUserVerifyNewDeviceResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x19\n\x11\x61pp_build_version\x18\x04 \x01(\r\x12\x13\n\x0b\x61pp_version\x18\x05 \x01(\t\x12!\n\x08platform\x18\x06 \x01(\x0e\x32\x0f.proto.Platform\x12\x18\n\x10platform_version\x18\x07 \x01(\t\x12\x1d\n\x06\x64\x65vice\x18\x08 \x01(\x0e\x32\r.proto.Device\x12\x13\n\x0b\x64\x65vice_name\x18\t \x01(\t\x12\x1d\n\x15two_step_verification\x18\n \x01(\x08\x42*\n\x0enet.iGap.protoB\x18ProtoUserVerifyNewDeviceb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERVERIFYNEWDEVICE = _descriptor.Descriptor(
  name='UserVerifyNewDevice',
  full_name='proto.UserVerifyNewDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserVerifyNewDevice.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.UserVerifyNewDevice.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=150,
)


_USERVERIFYNEWDEVICERESPONSE = _descriptor.Descriptor(
  name='UserVerifyNewDeviceResponse',
  full_name='proto.UserVerifyNewDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserVerifyNewDeviceResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='proto.UserVerifyNewDeviceResponse.app_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.UserVerifyNewDeviceResponse.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_build_version', full_name='proto.UserVerifyNewDeviceResponse.app_build_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='proto.UserVerifyNewDeviceResponse.app_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='proto.UserVerifyNewDeviceResponse.platform', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='proto.UserVerifyNewDeviceResponse.platform_version', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='proto.UserVerifyNewDeviceResponse.device', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='proto.UserVerifyNewDeviceResponse.device_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='two_step_verification', full_name='proto.UserVerifyNewDeviceResponse.two_step_verification', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=443,
)

_USERVERIFYNEWDEVICE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERVERIFYNEWDEVICERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERVERIFYNEWDEVICERESPONSE.fields_by_name['platform'].enum_type = Global__pb2._PLATFORM
_USERVERIFYNEWDEVICERESPONSE.fields_by_name['device'].enum_type = Global__pb2._DEVICE
DESCRIPTOR.message_types_by_name['UserVerifyNewDevice'] = _USERVERIFYNEWDEVICE
DESCRIPTOR.message_types_by_name['UserVerifyNewDeviceResponse'] = _USERVERIFYNEWDEVICERESPONSE

UserVerifyNewDevice = _reflection.GeneratedProtocolMessageType('UserVerifyNewDevice', (_message.Message,), dict(
  DESCRIPTOR = _USERVERIFYNEWDEVICE,
  __module__ = 'UserVerifyNewDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserVerifyNewDevice)
  ))
_sym_db.RegisterMessage(UserVerifyNewDevice)

UserVerifyNewDeviceResponse = _reflection.GeneratedProtocolMessageType('UserVerifyNewDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERVERIFYNEWDEVICERESPONSE,
  __module__ = 'UserVerifyNewDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserVerifyNewDeviceResponse)
  ))
_sym_db.RegisterMessage(UserVerifyNewDeviceResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\030ProtoUserVerifyNewDevice'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserUpdateStatus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserUpdateStatus.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16UserUpdateStatus.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\x86\x01\n\x10UserUpdateStatus\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.proto.UserUpdateStatus.Status\"!\n\x06Status\x12\n\n\x06ONLINE\x10\x00\x12\x0b\n\x07OFFLINE\x10\x01\"~\n\x18UserUpdateStatusResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.proto.UserUpdateStatus.Status\x12\x0f\n\x07user_id\x18\x08 \x01(\x04\x42\'\n\x0enet.iGap.protoB\x15ProtoUserUpdateStatusb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_USERUPDATESTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.UserUpdateStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ONLINE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFFLINE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=166,
  serialized_end=199,
)
_sym_db.RegisterEnumDescriptor(_USERUPDATESTATUS_STATUS)


_USERUPDATESTATUS = _descriptor.Descriptor(
  name='UserUpdateStatus',
  full_name='proto.UserUpdateStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserUpdateStatus.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.UserUpdateStatus.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERUPDATESTATUS_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=199,
)


_USERUPDATESTATUSRESPONSE = _descriptor.Descriptor(
  name='UserUpdateStatusResponse',
  full_name='proto.UserUpdateStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserUpdateStatusResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.UserUpdateStatusResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.UserUpdateStatusResponse.user_id', index=2,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=327,
)

_USERUPDATESTATUS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERUPDATESTATUS.fields_by_name['status'].enum_type = _USERUPDATESTATUS_STATUS
_USERUPDATESTATUS_STATUS.containing_type = _USERUPDATESTATUS
_USERUPDATESTATUSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERUPDATESTATUSRESPONSE.fields_by_name['status'].enum_type = _USERUPDATESTATUS_STATUS
DESCRIPTOR.message_types_by_name['UserUpdateStatus'] = _USERUPDATESTATUS
DESCRIPTOR.message_types_by_name['UserUpdateStatusResponse'] = _USERUPDATESTATUSRESPONSE

UserUpdateStatus = _reflection.GeneratedProtocolMessageType('UserUpdateStatus', (_message.Message,), dict(
  DESCRIPTOR = _USERUPDATESTATUS,
  __module__ = 'UserUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserUpdateStatus)
  ))
_sym_db.RegisterMessage(UserUpdateStatus)

UserUpdateStatusResponse = _reflection.GeneratedProtocolMessageType('UserUpdateStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERUPDATESTATUSRESPONSE,
  __module__ = 'UserUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserUpdateStatusResponse)
  ))
_sym_db.RegisterMessage(UserUpdateStatusResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoUserUpdateStatus'))
# @@protoc_insertion_point(module_scope)
